@@ -13,6 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import os
 import uuid
 
 from argparse import Namespace
@@ -21,31 +22,35 @@ from typing import Any, Dict, List, Optional, Union
 import packaging
 
 from polyaxon.client import RunClient
+from polyaxon.env_vars.keys import EV_KEYS_RUN_INSTANCE
 from traceml import tracking
 from traceml.exceptions import TracemlException
 
 try:
     import pytorch_lightning as pl
 
-    NEW_PL_VERSION = packaging.version.parse(pl.__version__) < packaging.version.parse(
-        "1.7"
-    )
+    NEW_PL_VERSION = packaging.version.parse(pl.__version__)
 
-    if NEW_PL_VERSION:
+    if NEW_PL_VERSION < packaging.version.parse("1.7"):
         from pytorch_lightning.loggers.base import LightningLoggerBase as Logger
         from pytorch_lightning.loggers.base import rank_zero_experiment
     else:
-        from pytorch_lightning.loggers.logger import (
-            Logger,
-            rank_zero_experiment,
-        )
+        from pytorch_lightning.loggers.logger import Logger, rank_zero_experiment
 
-    from pytorch_lightning.utilities.logger import (
-        _add_prefix,
-        _convert_params,
-        _flatten_dict,
-        _sanitize_callable_params,
-    )
+    if NEW_PL_VERSION < packaging.version.parse("1.9"):
+        from pytorch_lightning.utilities.logger import (
+            _add_prefix,
+            _convert_params,
+            _flatten_dict,
+            _sanitize_callable_params,
+        )
+    else:
+        from lightning_fabric.utilities.logger import (
+            _add_prefix,
+            _convert_params,
+            _flatten_dict,
+            _sanitize_callable_params,
+        )
     from pytorch_lightning.utilities.model_summary import ModelSummary
     from pytorch_lightning.utilities.rank_zero import rank_zero_only, rank_zero_warn
 except ImportError:
@@ -155,18 +160,43 @@ class Callback(Logger):
             self.experiment.end()
             self._experiment = None
 
+    def _set_run_instance_from_env_vars(self, force: bool = False):
+        """Tries to extract run info from canonical env vars"""
+        run_instance = os.getenv(EV_KEYS_RUN_INSTANCE)
+        if not run_instance:
+            return
+
+        parts = run_instance.split(".")
+        if len(parts) != 4:
+            return
+
+        if not self._name or force:
+            self._name = parts[2]
+        if not self._run_uuid or force:
+            self._run_uuid = parts[-1]
+
     @property
     def name(self) -> str:
         if self._experiment is not None and self._experiment.run_data.name is not None:
             return self.experiment.run_data.name
+
+        if not self._name:
+            self._set_run_instance_from_env_vars()
+
         if self._name:
             return self._name
+
         return "default"
 
     @property
     def version(self) -> str:
         if self._experiment is not None and self._experiment.run_data.uuid is not None:
             return self.experiment.run_data.uuid
+
+        if not self._run_uuid:
+            self._set_run_instance_from_env_vars()
+
         if self._run_uuid:
             return self._run_uuid
+
         return uuid.uuid4().hex
